if(!dojo._hasResource["com.ibm.data.CatalogMixin"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.CatalogMixin"] = true;
// Datastores written for use in the content search widget must inherit from this class to make the mapItem and prepareQuery function available to the widget
// These functions are used to unify access to datastores, so the widget can  query and access items the same way for every source

dojo.provide("com.ibm.data.CatalogMixin");
dojo.declare("com.ibm.data.CatalogMixin", 
		null,
		{	
			searchable: true,
			
			mapItem: function(/*DatstoreItem*/item){
				// summary: Returns a map containing parameters for the given datastore item
				//		The keys must be: label, description, tags, rating, url, id, thumbnail
				//			- label, description, url, id and thumbnail are strings
				//			- tags is an array of strings
				//			- rating is a string that contains a number, note that decimal values are allowed
				//		Having all content search datastores create item maps with the same keys allows the widget to access information uniformly
				// 		If a datastore item does not have the same attributes for getValue as seen below, this function must be overridden
				//		If a datastore item does not have an appropriate parameter to  map to a key, that map entry can be omitted
				//		An example for a datastore item with a title, summary, rating and identifier:
				//			mapItem: function(/*DatastoreItem*/item){
				//				// does not include the "tags" and "url" keys
				//				var map = {};
				//				map["label"] = this.getEPResolvedValue(item, "title", "untitled");
				//				map["description"] = this.getEPResolvedValue(item, "summary", null);
				//				map["rating"] = this.getEPResolvedValue(item, "rating", "0.0");
				//				map["id"] = this.getEPResolvedValue(item, "identifier", null);
				//				map["thumbnail"] = this.getEPResolvedValue(item, "thumbnail", null);
				//				return map;
				//			}
				var map = {};
				map["label"] = this.getEPResolvedValue(item, "label", "untitled");
				map["description"] = this.getEPResolvedValue(item, "description", null);
				map["tags"] = this.getEPResolvedValue(item, "tags", null);
				map["rating"] = this.getEPResolvedValue(item, "rating", "0.0");
				map["url"] = this.getEPResolvedValue(item, "url", null);
				map["id"] = this.getEPResolvedValue(item, "id", null);
				map["thumbnail"] = this.getEPResolvedValue(item, "thumbnail", null);
				return map;
			},

			prepareQuery: function(/*Object*/keywordArgs) {
				// summary: User overridable function to modify the keywordArgs object used to fetch results from the back end
				//		Called after the keywordArgs.query property has been normalized to an object map but before any other processing has taken place to build the URL
				//		After this function is called, anything in the keywordArgs.query map is appended to the fetch URL in the form (?|&)<key1>=<value1> &<key2>=<value2> &<key3>=<value3> ...
				//		Can be used to extract other parts of the keywordArgs map to add properties to the query object that are dependent on back end implementation
				//		Properties of the query object that are not part of the fetch URL should be deleted
				//		The keywordArgs object is defined in dojo.data.api.Read.fetch and query will be an object containing the key "keywords" with an array of strings as a value
				//		An example for a feed URL containing "searchTerms", "startIndex" and "count" parameters:
				//			prepareQuery: function(/*Object*/keywordArgs) {
				//				if(keywordArgs.query.keywords) {
				//					// searchTerms is a comma separated list of search parameters
				//					keywordArgs.query.searchTerms = keywordArgs.query.keywords.join(",");
				//					delete keywordArgs.query.keywords;
				//				}
				//				if(keywordArgs.count) {
				//					keywordArgs.query.count = keywordArgs.count;
				//					if(keywordArgs.start == null) {
				//						keywordArgs.start = 0;
				//					}
				//					keywordArgs.query.startIndex = keywordArgs.start;
				//				}
				//			}
				return keywordArgs;
			},
			
			validateSelf: function(){
				// summary: validates this datastore, if it does not validate the source will not be used
				// returns true for validation and false otherwise
				return true;
			},
			
			getSourceLabel: function(){
				return false;
			}
});

}
