if(!dojo._hasResource["com.ibm.mm.catalog.hubUtil"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.mm.catalog.hubUtil"] = true;
dojo.provide("com.ibm.mm.catalog.hubUtil");

/**
 * This is a utilities class which helps to get the server address of Mashup Hub from configuration file
 * and get the url of services provided by Mashup Hub.
 */
dojo.declare("com.ibm.mm.catalog.hubUtil", null, {
	
	paramServiceUrl			: '/client/hub/params/entryid/',
	openSearchUrl			: '/atom?',
	openSearchTemplateUrl   : '/atom/os.xml?',  
	securedUrl				: '/secured',
	anonymousUrl			: '/public',
	newFeedUrl				: '/permalink?landing=newfeed',
	newFeedMashupUrl		: '/permalink?landing=newmashup',
	newWidgetUrl			: '/permalink?landing=newwidget',
	openSearchPostUrl       : null,
	
	/**
	 * Read default Hub server url from configuration file.
	 * This may be changed later.
	 */
    getDefaultHubUrl: function(){
		var cs = com.ibm.mashups.services.ServiceManager.getService(com.ibm.mashups.enabler.services.ConfigService.SERVICE_NAME);
		return cs.getValue(com.ibm.mashups.enabler.services.ConfigConstants.HUB_URL);
	},
	
	/**
	 * get the anonymous access hub url, it's for "goto catalog"
	 */
	getHubAnonymousUrl: function() {	
		return this.getDefaultHubUrl() + this.anonymousUrl;		
	},
	
	/**
	 * get the secure hub url, it's for "goto catalog"
	 */
	getHubSecuredUrl: function() {	
		return this.getDefaultHubUrl() + this.securedUrl;		
	},
	
	/**
	 * Get the parameter service url of MashupHub
	 */
	getHubParameterServiceUrl: function(){
		return [this.getDefaultHubUrl(), this.paramServiceUrl].join("");
	},
	
	/**
	 * get the feed search url of MashupHub
	 */
	getHubOpenSearchUrl: function(){
		return [this.getDefaultHubUrl(), this.openSearchUrl].join("");
	},
	
	/**
	 * get the feed search template url of MashupHub
	 */
	getHubOpenSearchTemplateUrl: function(){
		return [this.getDefaultHubUrl(), this.openSearchTemplateUrl].join("");
	},
	
	/**
	 * get the "Create Feed" url of MashupHub
	 */
	getHubFeedCreationUrl: function(){
		return [this.getHubSecuredUrl(), this.newFeedUrl].join("");
	},
	
	/**
	 * get the "Create New Widget" url of MashupHub
	 */
	getHubWidgetCreationUrl: function(){
		return [this.getHubSecuredUrl(), this.newWidgetUrl].join("");
	},
	
	/**
	 * get the "Create Feed Mashup" url of MashupHub
	 */
	getHubFeedMashupCreationUrl: function(){
		return [this.getHubSecuredUrl(), this.newFeedMashupUrl].join("");
	},
	
	openSearchPost:function(callback,defaultUrl){
		if(!!this.openSearchPostUrl){
			if (this.openSearchPostUrl.length > 0){
				//post url has already initiated in previous request.
				
				callback(this.openSearchPostUrl);
			}else {
				//Previous success os.xml request does not return post url, use the defaultUrl
				callback(defaultUrl);
			}
		}else{
			var osURL = this.getHubOpenSearchTemplateUrl()+"collection=spaces";
			try {
				dojo.xhrGet({
					url: osURL,
					handleAs: "text",
					load: dojo.hitch(this, function(data){
						var doc = dojox.data.dom.createDocument(data);
						var urls = com.ibm.mashups.enabler.xml.XPath.evaluateXPath("//Url", doc);
						if (!!urls && urls.length > 0) {
							var url = urls[0].getAttribute("template");
							if (!!url && url.indexOf('?') > 0) {
								//post url found, all further os post will use this one.
								this.openSearchPostUrl = url.substring(0, url.indexOf('?'));
								callback(this.openSearchPostUrl);
								return;
							}
						}
						//os.xml does not return proper url template, use the hard-code one from defaultUrl.
						//Further request will not try to load the url in os.xml 
						this.openSearchPostUrl = "";
						callback(defaultUrl);
					}),
					error: dojo.hitch(this, function(){
						//Error happens while retrieve os.xml,use the hard-code one from defaultUrl.
						//Further request will try again to load url in os.xml
						callback(defaultUrl);
					})
				});
			}catch(e){
				//Error happens while retrieve os.xml,use the hard-code one from defaultUrl.
				//Further request will try again to load url in os.xml
				callback(defaultUrl);
			}
		}

	}
	
});

com.ibm.mm.catalog.hubUtil = new com.ibm.mm.catalog.hubUtil();

}
