// This is a sample for an Active Site Analytics aggregator.
//
// It injects a 1x1 pixel image into every page that has the metadata item "asa_aggregator" set to "asa_sample.js"
// The aggregator will assemble the image URL, containing a list of portlet ids and titles, as well as a number of additional data, as HTTP GET
// parameters, in the query part of the URL. The image is then added to the page (and requested by the browser, subsequently).
//
// Testing the sample aggregator
//
//  1. Follow the Infocenter topic "Adding an Active Site Analytics aggregator to a portal page"
//
//  2. In this script, change the value of the variable 'trackingImg' to point to location that is
//     reachable for a browser via HTTP (e.g. local Apache server).
//
//  3. Using a browser, load the page to which an aggregator was assigned in step 1
//
//  4. Check the log file of the HTTP server where the URL from step 2 points to.
//     It looks something like this:
//       http://example.com/tracking.gif?asa.portlet.id=xyz0987654321abc&asa.portlet.title=Example&asa.visitor=1234567890ABCDEFG&asa.url=/wps/myportal/Home/asa&asa.page.title=Sample_Page&asa.page.id=XYZ123ABC4567890&asa.page.breadcrumb=/Home/ASA" width="1" height="1">
//
//  5. Check that the query information contained in the requested URL corresponds to details of the page and portlets.
//
//  For debug purposes, the presence of the tracking picture in the DOM can be checked with dojo.query("[alt *= 'ASA']") on the client side, e.g. in FireBug.

var trackingImg = "http://example.com/tracking.gif";

// Subscribe to search events
dojo.subscribe("com.ibm.portal.search.RESULTS_ANALYTICS", function(e){
  // enable this statement for debugging
  //console.log(  "*** search term was '" + e.query
  //            + "' with " + e.results
  //            + " results in scope '" + e.scope.label + "' (" + e.scope.id + ")"
  //           );
});

// Only submit to analytics server once the page is complete
dojo.subscribe("com.ibm.portal.theme.portlet_ready", function(){
  var imgURL = trackingImg + "?" + retrieveData(dojo.query("[class *= 'asa']"));
  dojo.create("img", {src:imgURL, alt:"ASA Tracking Image"}, dojo.body());
  // console.log("*** page initially loaded. Reported URL is: " + imgURL); // enable this line for debugging
});

// Helper - extract all instances of asa microformats and return them as parameter string
function retrieveData(nodes){
  var result = new String();

  nodes.forEach(function(node, index, arr){
    var key = dojo.attr(node, "class").match(/asa\.[^\s]*/);
    var val = cleanup(dojox.xml.parser.textContent(node));

    if (0 < result.length)
      result += "&"

    result += escape(key) + "=" + escape(val);
  });

  return result;
}

// Helper - remove clutter from values
function cleanup(node_value){
   return dojo.map(node_value.split('/'), function(part){ return dojo.trim(part).replace('\n', '')}).join('/');
}
