dojo.provide("com.ibm.pb.contextMenu.JsonContextMenuLoader");

dojo.require("com.ibm.pb.data.ResourceLoader");
dojo.require("com.ibm.pb.logging.Loggable");
dojo.require("com.ibm.pb.localized.DojoLocalized");


dojo.declare("com.ibm.pb.contextMenu.JsonContextMenuLoader", [com.ibm.mashups.builder.model.ContextMenuLoader, com.ibm.pb.logging.Loggable], {
	
	/**
	 * Definition: 	{
	 * 					url: "",
	 * 					data: {},
	 * 					name: ""
	 * 				}
	 */
	_df: null,
	
	statusCodes: com.ibm.mm.enabler.model.HttpStatusCodes,
	
	constructor: function(/*Object*/ definition) {
		if(!definition) {
			throw new Error("definition must not be null");
		}
		this._df = definition;
		this._data = null;
	},
	getItems: function(/*String*/ contextMenuId, /*String*/ targetResourceId, /*String*/ targetResourceType, /*Object*/ someObject) {
		var mname = "getItems", lgr = this.LOGGER, me = this;
		lgr.entering(mname, arguments);
		dfd = new com.ibm.mm.builder.DeferredImpl(this, function(deferred, sync, params) {
			var callBack = deferred.getFinishedCallback(), callBackParams = deferred.getFinishedCallbackParameters(),
				res;
			if(!this._data) {
				this.getData(function(data, status){
					if(status == 200) {
						res = me._initMenuItems(contextMenuId, targetResourceId, targetResourceType, someObject);
					}
					else {
						res = data;
					}
					if(callBack){
						callBack(res, status, callBackParams);	// callback for success or error
					}
				}, sync);
			}
			else {
				res = this._initMenuItems(contextMenuId, targetResourceId, targetResourceType, someObject);
				if(callBack){
					callBack(res, 200, callBackParams);
				}
			}
			return res;
		});
		lgr.exiting(mname, arguments);
		return dfd;
	},
	getData: function(callback, sync) {
		var mname = "getData", lgr = this.LOGGER, me = this, jsonName = this._df.name, HTTP_OK = com.ibm.mm.enabler.model.HttpStatusCodes.HTTP_OK;
		lgr.entering(mname, arguments);
		if(!this._data) {
			if(this._df.data) {
				this._data = jsonName ? dojo.getObject(jsonName, false, this._df.data) : this._df.data;
				if(callback) {
					callback(this._data, 200);
				}
			}
			else if(this._df.url) {
				lgr.trace(mname, "Requesting context menu by url ${0}", [this._df.url]);
				com.ibm.pb.data.RESOURCE_LOADER.getData(this._df.url, "json").setFinishedCallback(function(data, status, params){
					me._data = data;
					if(status == 200 && jsonName) {
						me._data = dojo.getObject(jsonName, false, data);
					}
					if(callback) {
						callback(me._data, status);
					}
				}).start(sync);
			}
			else {
				throw new Error("Configuration error for context menu: Must specify url or data properties");
			}
		}
		lgr.exiting(mname, [this._data]);
		return this._data;
	},
	_initMenuItems: function(contextMenuId, targetResourceId, targetResourceType, someObject) {
		var mname = "_initMenuItems", lgr = this.LOGGER, ret = [],
			lclCtx = com.ibm.mashups.enabler.context.Factory.getLocalizedContext();
		// TODO: Add deferred processing support for visibility and state functions
		dojo.forEach(this._data, function(item){
			if(this._isVisible(item, targetResourceId, targetResourceType, someObject)) {
				lgr.trace(mname, "Adding item ${0}", [item.id]);
				var l7d = this._getLocalized(item);
				ret.push(dojo.delegate(item, {
					enabled: this._isEnabled(item, targetResourceId, targetResourceType, someObject),
					localized: l7d,
					title: item.title || lclCtx.getTitle(l7d), // if item's title is already defined, and perhaps calculated
					description: item.description || lclCtx.getDescription(l7d), // if item's description is already defined, and perhaps calculated
					actionCallBackFunction: this._getAction(item, targetResourceId, targetResourceType, someObject)
				}));
				lgr.trace(mname, "Added item ${0}", [item.id]);
			}
			else {
				lgr.trace(mname, "Item ${0} is hidden", [item.id]);
			}
		}, this);
		return ret;
	},
	_getAction: function(item, targetResourceId, targetResourceType, someObject) {
		var mname = "_getAction", lgr = this.LOGGER;
		lgr.entering(mname, [item.id, targetResourceId, targetResourceType, someObject]);
		var ret = dojo.partial(item.actionFn, targetResourceId, targetResourceType, item.metadata, someObject);
		lgr.exiting(mname, [item.id, ret]);
		return ret;
	},
	_isVisible: function(item, targetResourceId, targetResourceType, someObject) {
		var mname = "_isVisible", lgr = this.LOGGER;
		lgr.entering(mname, [item.id, targetResourceId, targetResourceType, someObject]);
		var ret = false;
		try {
			ret = dojo.isFunction(item.visibilityFn) ? dojo.partial(item.visibilityFn)(targetResourceId, targetResourceType, item.metadata, someObject) : true;
		} catch(err) {
			lgr.severe(mname, "Error executing visibilityFn for item ${0}: ${1}", [item, err]);
		}
		lgr.exiting(mname, [item.id, ret]);
		return ret;
	},
	_isEnabled: function(item, targetResourceId, targetResourceType, someObject) {
		var mname = "_isEnabled", lgr = this.LOGGER;
		lgr.entering(mname, [item.id, targetResourceId, targetResourceType, someObject]);
		var ret = false;
		try {
			ret = item.stateFn ? item.stateFn(targetResourceId, targetResourceType, item.metadata, someObject) : item.enabled;
		} catch(err) {
			lgr.severe(mname, "Error executing stateFn ${0}", [err]);
		}
		lgr.exiting(mname, [item.id, ret]);
		return ret;
	},
	_getLocalized: function(item) {
		return new com.ibm.pb.localized.DojoLocalized(item);
	}
});