/* Copyright IBM Corp. 2013  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.data.util");
dojo.provide("com.ibm.mashups.data.Util");

dojo.require("com.ibm.mm.data.table");
/**
 * Defines methods that are commonly used utilities when working with Mashups' standard data types.
 * @ibm-module Legacy
 */
dojo.declare("com.ibm.mashups.data.Util", null, {
    /**
     * This method ensures that one cell of CSV data is properly formatted as defined by <a href="http://dojotoolkit.org/book/dojo-book-0-9/part-3-programmatic-dijit-and-dojo/what-dojo-data/available-stores/dojox-data-csv">dojox.data.CsvStore</a> with internal double-quotes doubled and external double quotes if internal double-quotes or commas.
     * @param {String} cell The cell of data to format.
     * @type String
     * @return {String} Return the cell of data properly formatted.
     */
    encodeCSVCell: function(cell) {
        cell = "" + cell;
        var result = cell.replace(/"/g, '""');
        if (result.indexOf(',') >= 0 || result.indexOf('"') >= 0) {
            result = '"' + result + '"';
        }
        result = result.replace(/\n/g, "");
        return result;
    },
    
    /**
     * This method converts an object or array of objects into a CSV data string that is properly formatted as defined by <a href="http://dojotoolkit.org/book/dojo-book-0-9/part-3-programmatic-dijit-and-dojo/what-dojo-data/available-stores/dojox-data-csv">dojox.data.CsvStore</a>.
     * @param {Object} json The object or array of objects to convert to CSV.
     * @type String
     * @return {String} Return the CSV data string.
     */
    JSONObject2CSV: function(json) {
        if (!dojo.isArray(json)) {
            json = [json];
        }
        var rowColumnName = '', rowData = '';
        var firstKey = true;
        for (var i = 0; i < json.length; i++) {
            firstKey = true;
            var jsonData = json[i];
            for (var key in jsonData) {
                if (Object.prototype.hasOwnProperty.call(jsonData,key)) {
                    if (i === 0) {
                        if (!firstKey) {
                            rowColumnName += ",";
                        }
                        rowColumnName += this.encodeCSVCell(key);
                    }
                    if (!firstKey) {
                        rowData += ",";
                    }
                    rowData += this.encodeCSVCell(json[i][key]);
                    firstKey = false;
                }
            }
            if (i === 0) {
                rowColumnName += '\n';
            }
            rowData += '\n';
        }
        return rowColumnName + rowData;
    },
    
    /**
     * This method converts an object or array of objects into the Mashups' standard table data type.
     * @param {Object} json The object or array of objects to convert to table data type.
     * @type com.ibm.mm.data.table
     * @return {com.ibm.mm.data.table} Return the target data formatted as the Mashups' standard table data type.
     */
    JSONObject2Table: function(json) {
        var csv = this.JSONObject2CSV(json);
        var table = new com.ibm.mm.data.table({
            data: csv
        });
        return table;
    }
});

com.ibm.mashups.data.Util = new com.ibm.mashups.data.Util();
