/* Copyright IBM Corp. 2013  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.navigation.persistence.TypeMappingRegistry");

//<INTERFACE>
/**
 * Registry to set type mappings. Type mappings map custom artifacts to enabler types.
 */
dojo.declare("com.ibm.mashups.enabler.navigation.persistence.TypeMappingRegistry", null, {
    /**
     * Adds a custom type mapping filter.<br>
     * In order to determine the type of a resource, the set filters are processed one after
     * another by invoking the filter function with the artifact's underlying data representation,
     * i.e. json or xml. If a filter function returns a type, the resource is resolved to this
     * type. If a filter returns <code>null</code>, the next filter is processed until the type
     * of the artifact can be resolved, or all filters are processed. The filters added last are
     * processed first.
     * @param {Object} filter filter object defined as follows:<br>
     * <tt>filter = {</tt><br>
     * &nbsp;&nbsp;<tt>json: {</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>fn: FUNCTION,</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>scope: SCOPE</tt><br>
     * &nbsp;&nbsp;<tt>},</tt><br>
     * &nbsp;&nbsp;<tt>xml: {</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>fn: FUNCTION,</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>scope: SCOPE</tt><br>
     * &nbsp;&nbsp;<tt>}</tt><br>
     * <tt>}</tt><br>
     * where
     * <ul>
     * <li><tt>FUNCTION</tt> is a function defined as <tt>type function(data)</tt>, which
     * returns the type of the input data, or <code>null</code> if the type is not recognized 
     * with this filter. The returned type must be one of the following:
     * <ul>
     * <li><tt>com.ibm.mashups.enabler.navigation.Constants.NAVIGATION_PAGE</tt></li>
     * <li><tt>com.ibm.mashups.enabler.navigation.Constants.NAVIGATION_LABEL</tt></li>
     * <li><tt>com.ibm.mashups.enabler.navigation.Constants.NAVIGATION_URL</tt></li>
     * </ul>
     * The filter function is mandatory.
     * </li>
     * <li><tt>SCOPE</tt> is the scope to execute the filter function in; optional, 
     * defaults to global scope</li>
     * </ul><br>
     * Notes:
     * <ul>
     * <li>You may specify a filter for json, xml, or both with one filter.</li>
     * <li>You may specify a filter to resolve to one or multiple types.</li>
     * <li>Resources must be resolvable to a type in all representations it can occur in. Otherwise, representation switching might not work correctly.</li>
     * <li>Primed resources are considered to be in json representation.</li>
     * </ul><br>
     * <b>Example:</b><br>
     * <tt>com.ibm.mashups.enabler.navigation.persistence.TypeMappingRegistry.addTypeMappingFilter({</tt><br>
     * &nbsp;&nbsp;<tt>json: {</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>fn: function(data){</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<tt>return data.type == "customPageType" ? com.ibm.mashups.enabler.navigation.Constants.NAVIGATION_PAGE : null;</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>}</tt><br>
     * &nbsp;&nbsp;<tt>}</tt><br>
     * <tt>});</tt>
     * @type void
     * 
     * @since 3.0.0.2
     * @ibm-spi
     * @ibm-module CoreModel
     */
    addTypeMappingFilter: function(filter){
    }
});
//</INTERFACE>
dojo.require("com.ibm.mm.enabler.navigation.persistence.TypeMappingRegistryImpl");
